/*
 * Copyright 2016 University of Chicago
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * @file start.c
 * Implementation of the s3 DSI start session
 */
#include "globus_gridftp_server_s3_base.h"

/**
 * @brief destroy
 * @details
 * This is called when a session ends, ie client quits or disconnects.
 * The dsi should clean up all memory they associated with the session
 * here. 
 */
void
globus_i_s3_destroy(
    void                               *user_arg)
{
    globus_i_s3_handle_t               *s3_handle = user_arg;

    if (!s3_handle)
    {
        return;
    }

    free(s3_handle->accessKeyId);
    free(s3_handle->secretAccessKey);
    free(s3_handle->securityToken);
    free(s3_handle);
}
/* globus_i_s3_destroy() */
// vim: ft=c:
